@@ -29,16 +29,10 @@ def _get_full_url(url, srcurl):
     if url[:4] == 'http':
         return url
 
-    urlp = urlparse(srcurl)
-
     # remove everything after last / in the path of the URL
     baseurl = re.sub(r'^([^\?]+)/[^/]*(\?.*)?$', r'\1', srcurl)
     returl = "%s/%s" % (baseurl, url)
 
-    # Append optional query parameters
-    if urlp.query:
-        returl += "?%s" % urlp.query
-
     return returl
 
 
@@ -110,6 +104,7 @@ class HLS(VideoRetriever):
         if self.options.output != "-":
             file_d.close()
             progress_stream.write('\n')
+            self.finished = True
 
 
 def parsem3u(data):
